@@ -68,12 +68,10 @@ def _install_labextensions(lab):
     if lab:
         subprocess.check_call(["jupyter", "labextension", "install", "@jupyter-widgets/jupyterlab-manager"])
         subprocess.check_call(["jupyter", "labextension", "install", "beakerx-jupyterlab"])
-        subprocess.check_call(["jupyter", "labextension", "install", "beakerx-jupyterlab-js"])
 
 
 def _uninstall_labextensions(lab):
     if lab:
-        subprocess.check_call(["jupyter", "labextension", "uninstall", "beakerx-jupyterlab-js"])
         subprocess.check_call(["jupyter", "labextension", "uninstall", "beakerx-jupyterlab"])
         subprocess.check_call(["jupyter", "labextension", "uninstall", "@jupyter-widgets/jupyterlab-manager"])
 
@@ -144,6 +142,7 @@ def _install_magics():
     with open(os.path.join(dir_path, 'ipython_config.py'), 'w+') as ipython_config:
         ipython_config.write("c = get_config()\n")
         ipython_config.write("c.InteractiveShellApp.extensions = ["
+                             "'beakerx.autotranslation',\n"
                              "'beakerx_magics.kernel_magic',\n"
                              "'beakerx_magics.groovy_magic',\n"
                              "'beakerx_magics.clojure_magic',\n"
